# -*- coding: utf-8 -*-

# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# suites.py - definitions of AccelerateWP feature suites

from typing import Set
import os
from clcommon.lib.cledition import is_cl_solo_edition

from clwpos.optimization_features import (
    Feature,
    OBJECT_CACHE_FEATURE,
    SITE_OPTIMIZATION_FEATURE,
    CDN_FEATURE
)
from dataclasses import dataclass


PREMIUM_ENABLE_FLAG = '/var/lve/enable-wpos.flag'
IS_FREE_SUITE_ALLOWED_BY_DEFAULT = bool(is_cl_solo_edition())
# TODO: discuss this with Dennis
IS_PREMIUM_SUITE_ALLOWED_BY_DEFAULT = is_cl_solo_edition() and os.path.isfile(PREMIUM_ENABLE_FLAG)
IS_CDN_SUITE_ALLOWED_BY_DEFAULT = is_cl_solo_edition()


@dataclass
class Suite:
    """Base Suite implementation"""
    name: str
    features: Set
    # for some cases we need to handle only primary feature (e.g for CDN suite = cdn feature)
    primary: Set
    is_allowed_by_default: bool
    @property
    def feature_set(self) -> Set[Feature]:
        """"""
        return self.features
    @property
    def primary_features(self) -> Set[Feature]:
        """"""
        return self.primary


AWPSuite = Suite(
    name='accelerate_wp',
    features={
        SITE_OPTIMIZATION_FEATURE
    },
    primary={
        SITE_OPTIMIZATION_FEATURE
    },
    is_allowed_by_default=IS_FREE_SUITE_ALLOWED_BY_DEFAULT
)

PremiumSuite = Suite(
    name='accelerate_wp_premium',
    features={
        OBJECT_CACHE_FEATURE
    },
    primary={
        OBJECT_CACHE_FEATURE
    },
    is_allowed_by_default=IS_PREMIUM_SUITE_ALLOWED_BY_DEFAULT
)

CDNSuite = Suite(
    name='accelerate_wp_cdn',
    features={
        SITE_OPTIMIZATION_FEATURE,
        CDN_FEATURE
    },
    primary={
        CDN_FEATURE
    },
    is_allowed_by_default=IS_CDN_SUITE_ALLOWED_BY_DEFAULT
)


ALL_SUITES = {
    AWPSuite.name: AWPSuite,
    PremiumSuite.name: PremiumSuite,
    CDNSuite.name: CDNSuite
}

# for backward compatibility with old configs
OLD_NEW_SUITE_NAME_PAIRS = {
    'object_cache': 'accelerate_wp_premium',
    'site_optimization': 'accelerate_wp'
}
